@@ -1,7 +1,6 @@
 import pandas as pd
 
-from azure_helper.utils.aml_interface import AMLInterface
-from azure_helper.utils.blob_storage_interface import BlobStorageInterface
+from azure_helper.interfaces.blob_storage_interface import BlobStorageInterface
 
 
 class CreateData:
@@ -11,6 +10,14 @@ class CreateData:
         train_datastore: str = "train",
         test_datastore: str = "test",
     ):
+        """This class is just a wrapper around the [BlobStorageInterface][azure_helper.utils.blob_storage_interface] and
+        might disappear, as it is not really needed.
+
+        Args:
+            project_name (str): _description_
+            train_datastore (str, optional): _description_. Defaults to "train".
+            test_datastore (str, optional): _description_. Defaults to "test".
+        """
         self.project_name = project_name
         self.train_datastore = train_datastore
         self.test_datastore = test_datastore
@@ -21,6 +28,13 @@ class CreateData:
         x_train: pd.DataFrame,
         y_train: pd.DataFrame,
     ):
+        """Upload datas to the training blob storage.
+
+        Args:
+            blob_storage_interface (BlobStorageInterface): The interface with your storage account.
+            x_train (pd.DataFrame): Train datas.
+            y_train (pd.DataFrame): Train datas.
+        """
         blob_storage_interface.upload_df_to_blob(
             dataframe=x_train,
             container_name=f"{self.project_name}",
@@ -38,6 +52,13 @@ class CreateData:
         x_valid: pd.DataFrame,
         y_valid: pd.DataFrame,
     ):
+        """Upload datas to the validation blob storage.
+
+        Args:
+            blob_storage_interface (BlobStorageInterface): The interface with your storage account.
+            x_valid (pd.DataFrame): Validation datas.
+            y_valid (pd.DataFrame): Validation datas.
+        """
         # Data to be used during model validation
         blob_storage_interface.upload_df_to_blob(
             dataframe=x_valid,
@@ -56,6 +77,13 @@ class CreateData:
         x_test: pd.DataFrame,
         y_test: pd.DataFrame,
     ):
+        """Upload datas to the test blob storage.
+
+        Args:
+            blob_storage_interface (BlobStorageInterface): The interface with your storage account.
+            x_test (pd.DataFrame): Test datas.
+            y_test (pd.DataFrame): Test datas.
+        """
         # Data to be used during model evaluation
         # So stored in the training container
         blob_storage_interface.upload_df_to_blob(
